==> igniteui-react-charts-18.5.0-beta.0.tgz: package/esm5/lib/Stacked100SplineAreaSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StackedSplineAreaSeries } from "./StackedSplineAreaSeries";
import { IStacked100Series_$type } from "./IStacked100Series";
import { markType } from "igniteui-react-core";
import { Stacked100DataPreparer } from "./Stacked100DataPreparer";
import { StackedSplineAreaSeriesView } from "./StackedSplineAreaSeriesView";
import { Defaults } from "./Defaults";
/**
 * @hidden
 */
var Stacked100SplineAreaSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100SplineAreaSeries, _super);
    function Stacked100SplineAreaSeries() {
        var _this = _super.call(this) || this;
        _this.ab = Stacked100SplineAreaSeries.$;
        return _this;
    }
    Stacked100SplineAreaSeries.prototype.cg = function () {
        return new Stacked100SplineAreaSeriesView(this);
    };
    Stacked100SplineAreaSeries.prototype.o0 = function (a) {
        _super.prototype.o0.call(this, a);
        this.yo = a;
    };
    Stacked100SplineAreaSeries.prototype.get_xn = function () {
        return true;
    };
    Stacked100SplineAreaSeries.prototype.ac = function () {
        _super.prototype.ac.call(this);
        this.pp(false);
    };
    Stacked100SplineAreaSeries.prototype.x3 = function () {
        _super.prototype.x3.call(this);
        Stacked100DataPreparer.a(this);
    };
    Object.defineProperty(Stacked100SplineAreaSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.wi;
        },
        enumerable: false,
        configurable: true
    });
    Stacked100SplineAreaSeries.$t = markType(Stacked100SplineAreaSeries, 'Stacked100SplineAreaSeries', StackedSplineAreaSeries.$, [IStacked100Series_$type]);
    return Stacked100SplineAreaSeries;
}(StackedSplineAreaSeries));
export { Stacked100SplineAreaSeries };
/**
 * @hidden
 */
var Stacked100SplineAreaSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100SplineAreaSeriesView, _super);
    function Stacked100SplineAreaSeriesView(a) {
        return _super.call(this, a) || this;
    }
    Stacked100SplineAreaSeriesView.prototype.au = function () {
        _super.prototype.au.call(this);
        if (!this.q) {
            this.c3.ua = Defaults.e;
        }
    };
    Stacked100SplineAreaSeriesView.$t = markType(Stacked100SplineAreaSeriesView, 'Stacked100SplineAreaSeriesView', StackedSplineAreaSeriesView.$);
    return Stacked100SplineAreaSeriesView;
}(StackedSplineAreaSeriesView));
export { Stacked100SplineAreaSeriesView };

==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm5/lib/Stacked100SplineAreaSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StackedSplineAreaSeries } from "./StackedSplineAreaSeries";
import { IStacked100Series_$type } from "./IStacked100Series";
import { markType } from "igniteui-react-core";
import { Stacked100DataPreparer } from "./Stacked100DataPreparer";
import { StackedSplineAreaSeriesView } from "./StackedSplineAreaSeriesView";
import { Defaults } from "./Defaults";
/**
 * @hidden
 */
var Stacked100SplineAreaSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100SplineAreaSeries, _super);
    function Stacked100SplineAreaSeries() {
        var _this = _super.call(this) || this;
        _this.ab = Stacked100SplineAreaSeries.$;
        return _this;
    }
    Stacked100SplineAreaSeries.prototype.cr = function () {
        return new Stacked100SplineAreaSeriesView(this);
    };
    Stacked100SplineAreaSeries.prototype.qz = function (a) {
        _super.prototype.qz.call(this, a);
        this.ab1 = a;
    };
    Stacked100SplineAreaSeries.prototype.get_aaz = function () {
        return true;
    };
    Stacked100SplineAreaSeries.prototype.ac = function () {
        _super.prototype.ac.call(this);
        this.rp(false);
    };
    Stacked100SplineAreaSeries.prototype.abg = function () {
        _super.prototype.abg.call(this);
        Stacked100DataPreparer.a(this);
    };
    Stacked100SplineAreaSeries.prototype.aa5 = function (a, b) {
        var c = 0;
        for (var d = 0; d < this.series.count; d++) {
            c += this.series._inner[d].ak.item(b);
        }
        return (this.series._inner[a].ak.item(b) / c) * 100;
    };
    Object.defineProperty(Stacked100SplineAreaSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.zl;
        },
        enumerable: false,
        configurable: true
    });
    Stacked100SplineAreaSeries.$t = markType(Stacked100SplineAreaSeries, 'Stacked100SplineAreaSeries', StackedSplineAreaSeries.$, [IStacked100Series_$type]);
    return Stacked100SplineAreaSeries;
}(StackedSplineAreaSeries));
export { Stacked100SplineAreaSeries };
/**
 * @hidden
 */
var Stacked100SplineAreaSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100SplineAreaSeriesView, _super);
    function Stacked100SplineAreaSeriesView(a) {
        return _super.call(this, a) || this;
    }
    Stacked100SplineAreaSeriesView.prototype.au = function () {
        _super.prototype.au.call(this);
        if (!this.q) {
            this.c5.w5 = Defaults.e;
        }
    };
    Stacked100SplineAreaSeriesView.$t = markType(Stacked100SplineAreaSeriesView, 'Stacked100SplineAreaSeriesView', StackedSplineAreaSeriesView.$);
    return Stacked100SplineAreaSeriesView;
}(StackedSplineAreaSeriesView));
export { Stacked100SplineAreaSeriesView };
